@@ -84,6 +84,18 @@ mod_Square_Lattice_ui <- function(id){
         width = 8,
         fluidRow(
           tabsetPanel(
+            tabPanel(
+              "Summary Design",
+              br(),
+              div(
+                shinycssloaders::withSpinner(
+                  verbatimTextOutput(outputId = ns("summary_square_lattice"), 
+                                     placeholder = FALSE), 
+                  type = 4
+                ),
+                style = "padding-right: 40px;"
+              )
+            ),
             tabPanel("Field Layout",
                      shinyjs::useShinyjs(),
                      shinyjs::hidden(downloadButton(ns("downloadCsv.square"), 
@@ -304,6 +316,12 @@ mod_Square_Lattice_server <- function(id){
       
     })
     
+    output$summary_square_lattice <- renderPrint({
+      req(SQUARE_reactive())
+        cat("Randomization was successful!", "\n", "\n")
+        print(SQUARE_reactive(), n = 6)
+    })
+    
     upDateSites_SQ <- reactive({
       req(square_inputs())
       locs <- square_inputs()$sites
