@@ -529,7 +529,6 @@ plot_iblocks_1 <- function(
       flip = FALSE,
       out1 = REP,
       out2 = IBLOCK,
-      col = IBLOCK,
       out2.gpar = list(col = "black", lty = 3),
       text = ENTRY,
       cex = 1,
@@ -541,7 +540,11 @@ plot_iblocks_1 <- function(
       show.key = FALSE,
       gg = TRUE
     )
+    
+    p1 <- add_gg_features(p1)
+    
     df$REP <- as.factor(df$REP)
+
     p2 <- desplot::desplot(
       REP ~ COLUMN + ROW,
       flip = FALSE,
@@ -552,6 +555,8 @@ plot_iblocks_1 <- function(
       show.key = FALSE,
       gg = TRUE
     )
+    
+    p2 <- add_gg_features(p2)
   }
   return(
     list(
@@ -563,3 +568,28 @@ plot_iblocks_1 <- function(
     )
   )
 }
+
+add_gg_features <- function(ggplot2_obj) {
+  p1 <- ggplot2_obj
+  # Explicitly remove all legends
+  p1 <- p1 + ggplot2::guides(
+    fill = "none",   # Remove legend for fill
+    color = "none",  # Remove legend for color (if used)
+    text = "none"    # Remove legend for text labels
+  )
+  
+  # Format the x and y axes to show integer labels
+  p1 <- p1 +
+    ggplot2::scale_x_continuous(breaks = function(x) seq(floor(min(x)), ceiling(max(x)), by = 1)) +
+    ggplot2::scale_y_continuous(breaks = function(x) seq(floor(min(x)), ceiling(max(x)), by = 1))
+  
+  # Apply a minimal theme for better aesthetics
+  p1 <- p1 + ggplot2::theme_minimal() +
+    ggplot2::theme(
+      plot.title = ggplot2::element_text(face = "bold", size = 12),
+      axis.title = ggplot2::element_text(size = 11),
+      axis.text = ggplot2::element_text(size = 10)
+    )
+  
+  return(p1)
+}
